@@ -16,15 +16,14 @@ GeomSplitViolin <- ggproto("GeomSplitViolin", GeomViolin,
       both <- cbind(quantiles, aesthetics)
       quantile_grob <- GeomPath$draw_panel(both, ...)
       ggplot2:::ggname("geom_split_violin", grid::grobTree(GeomPolygon$draw_panel(newdata, ...), quantile_grob))
-    }
-    else {
+    } else {
       ggplot2:::ggname("geom_split_violin", GeomPolygon$draw_panel(newdata, ...))
     }
   }
 )
 # Visualize Violin plot
 create_quantile_segment_frame <- function(data, draw_quantiles, split = FALSE, grp = NULL) {
-  interleave <- "ggplot2" %:::% "interleave"
+  interleave <- "vctrs" %:::% "vec_interleave"
   dens <- cumsum(data$density) / sum(data$density)
   suppressWarnings(ecdf <- stats::approxfun(dens, data$y))
   ys <- ecdf(draw_quantiles)
