@@ -5,7 +5,7 @@
 #' extra data from Zenodo, e.g., `options(xena.zenodoDir = "/home/xxx/dataset")`.
 #'
 #' @param name a dataset name. Could be one of
-#' 
+#'
 #' **Builtin datasets**:
 #'   - `ccle_absolute`: CCLE ABSOLUTE result.
 #'   - `ccle_info`: CCLE information.
@@ -23,7 +23,7 @@
 #'   - `TCGA.organ`: TCGA organ data.
 #'   - `toil_info`: Toil hub information.
 #'
-#' **Remote datasets stored in [Zenodo](https://zenodo.org/record/10977637/)**:
+#' **Remote datasets stored in [Zenodo](https://zenodo.org/record/12819839/)**:
 #'   - `pcawg_promoter_id`: PCAWG promoter identifiers.
 #'   - `transcript_identifier`: Common transcript identifiers.
 #'   - `ccle_expr_and_drug_response`: CCLE expression and drug response data.
@@ -44,7 +44,7 @@
 #'   - `pcawg_PW`: ssGSEA scores of HALLMARK, KEGG, IOBR terms for PCAWG samples.
 #'   - ...
 
-#'   
+#'
 #' @return a dataset, typically a `data.frame`.
 #' @export
 #'
@@ -79,9 +79,10 @@ load_data <- function(name) {
     if (!file.exists(data_path)) {
       # Download it to inst/extdata from zenodo
       # Then load it
-      data_url <- file.path("https://zenodo.org/record/10977637/files", name2)
-      if (tryCatch(httr::status_code(httr::HEAD(data_url)), 
-                   error = function(e) 404) != 200) {
+      data_url <- file.path("https://zenodo.org/record/12819839/files", name2)
+      if (tryCatch(httr::status_code(httr::HEAD(data_url)),
+        error = function(e) 404
+      ) != 200) {
         # Use an alternative OSS approach
         data_url <- file.path("https://ucscxenashiny-1301043367.cos.ap-shanghai.myqcloud.com", name2)
       }
