@@ -119,23 +119,25 @@ vis_toil_TvsN <- function(Gene = "TP53", Mode = c("Boxplot", "Violinplot"),
     )
 
     if (Show.P.value == TRUE & Show.P.label == TRUE) {
-      p <- p + ggplot2::geom_text(aes(
-        x = .data$tissue,
-        y = max(tcga_gtex_withNormal$value) * 1.1,
-        label = .data$p.signif
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        aes(
+          x = .data$tissue,
+          y = max(tcga_gtex_withNormal$value) * 1.1,
+          label = .data$p.signif
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
     if (Show.P.value == TRUE & Show.P.label == FALSE) {
-      p <- p + ggplot2::geom_text(aes(
-        x = .data$tissue,
-        y = max(tcga_gtex_withNormal$value) * 1.1,
-        label = as.character(signif(.data$p, 2))
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        aes(
+          x = .data$tissue,
+          y = max(tcga_gtex_withNormal$value) * 1.1,
+          label = as.character(signif(.data$p, 2))
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
   }
@@ -192,23 +194,25 @@ vis_toil_TvsN <- function(Gene = "TP53", Mode = c("Boxplot", "Violinplot"),
     )
 
     if (Show.P.value == TRUE & Show.P.label == TRUE) {
-      p <- p + ggplot2::geom_text(ggplot2::aes(
-        x = .data$tissue,
-        y = max(tcga_gtex_withNormal$value) * 1.1,
-        label = .data$p.signif
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        ggplot2::aes(
+          x = .data$tissue,
+          y = max(tcga_gtex_withNormal$value) * 1.1,
+          label = .data$p.signif
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
     if (Show.P.value == TRUE & Show.P.label == FALSE) {
-      p <- p + ggplot2::geom_text(ggplot2::aes(
-        x = .data$tissue,
-        y = max(tcga_gtex_withNormal$value) * 1.1,
-        label = as.character(signif(.data$p, 2))
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        ggplot2::aes(
+          x = .data$tissue,
+          y = max(tcga_gtex_withNormal$value) * 1.1,
+          label = as.character(signif(.data$p, 2))
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
   }
@@ -219,20 +223,21 @@ vis_toil_TvsN <- function(Gene = "TP53", Mode = c("Boxplot", "Violinplot"),
 #'
 #' @inheritParams vis_toil_TvsN
 #' @param measure a survival measure, e.g. "OS".
-#' @param threshold a expression cutoff, `0.5` for median.
-#' @param data_type choose gene profile type, including "mRNA","transcript","methylation","miRNA","protein","cnv"
+#' @param data_type choose gene profile type, including "mRNA","transcript","methylation","miRNA","protein","mutation","cnv"
+#' @param use_optimal_cutoff use `surv_cutpoint` from survminer package for
+#' thresholding samples in each cancer type.
 #' @return a `ggplot` object
 #' @examples
 #' \dontrun{
 #' p <- vis_unicox_tree(Gene = "TP53")
 #' }
 #' @export
-vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA", 
-      threshold = 0.5, values = c("grey", "#E31A1C", "#377DB8"), opt_pancan = .opt_pancan) {
+vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA", use_optimal_cutoff = FALSE,
+                            values = c("grey", "#E31A1C", "#377DB8"), opt_pancan = .opt_pancan) {
   tcga_surv <- load_data("tcga_surv")
   tcga_gtex <- load_data("tcga_gtex")
 
-  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan=opt_pancan)
+  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan = opt_pancan)
   if (is.null(t1[[1]])) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
@@ -242,34 +247,40 @@ vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA",
     message("All NAs returned, return NULL instead.")
     return(NULL)
   }
-  
+
   # we filter out normal tissue
   tcga_gtex <- tcga_gtex %>% dplyr::filter(.data$type2 != "normal")
 
   message(paste0("Get data value for ", Gene))
-  s <- data.frame(sample = names(t1), values = t1)
+  # NA values could appear, especially in signature calculation:
+  # For instance, patient-1 expressed GeneA, but not expressed GeneB, then
+  # signature GeneA + GeneB will be NA for patient-1
+  s <- data.frame(sample = names(t1), values = t1) %>%
+    dplyr::filter(!is.na(.data$values)) 
   ## we use median cutoff here
   ss <- s %>%
+    dplyr::filter(!is.na(.data$values)) %>% 
     dplyr::inner_join(tcga_surv, by = "sample") %>%
     dplyr::inner_join(tcga_gtex[, c("tissue", "sample")], by = "sample")
   sss <- split(ss, ss$tissue)
+  # discard cancer types with constant values
+  sss = sss[sapply(sss, function(x){stats::sd(x$values)!=0})]
   tissues <- names(sss)
-  unicox_res_all_cancers <- purrr::map(tissues, purrr::safely(function(cancer) {
-    # cancer = "ACC"
+  .f <- function(cancer) {
     sss_can <- sss[[cancer]]
-    if (threshold == 0.5) {
+    # By default, cox analysis based on continuous molecule values. HR>0: Higher values, More risky. 
+    # Set use_optimal_cutoff as TRUE: Divide into 2 groups (Low/High) according the optimal cutoff. Then, 
+    ## cox analysis based on discrete molecule groups. HR>0: 'High' Group are more risky.
+    if (use_optimal_cutoff) {
       sss_can <- sss_can %>%
-        dplyr::mutate(group = ifelse(.data$values > stats::median(.data$values), "high", "low")) %>%
-        dplyr::mutate(group = factor(.data$group, levels = c("low", "high")))
-    }
-
-    if (threshold == 0.25) {
-      sss_can <- sss_can %>%
-        dplyr::mutate(group = ifelse(.data$values > stats::quantile(.data$values)[4], "high",
-          ifelse(.data$values < stats::quantile(.data$values)[2], "low", "middle")
-        )) %>%
-        dplyr::filter(group != "middle") %>%
-        dplyr::mutate(group = factor(.data$group, levels = c("low", "high")))
+        survminer::surv_cutpoint(
+          time = paste0(measure, ".time"), event = measure,
+          variables = c("values"),
+          minprop = 0.25, progressbar = TRUE
+        ) %>%
+        survminer::surv_categorize(labels = c("Low", "High")) %>%
+        data.frame() %>%
+        dplyr::mutate(values = factor(values, levels = c("Low", "High")))
     }
 
     unicox_res_genes <- ezcox::ezcox(
@@ -285,7 +296,8 @@ vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA",
     unicox_res_genes$cancer <- cancer
     unicox_res_genes$measure <- measure
     return(unicox_res_genes)
-  })) %>% magrittr::set_names(tissues)
+  }
+  unicox_res_all_cancers <- purrr::map(tissues, purrr::safely(.f)) %>% magrittr::set_names(tissues)
 
   unicox_res_all_cancers <- unicox_res_all_cancers %>%
     purrr::map(~ .x$result) %>%
@@ -298,11 +310,11 @@ vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA",
     dplyr::mutate(Type = ifelse(.data$p.value < 0.05 & .data$HR_log > 0, "Risky", ifelse(.data$p.value < 0.05 & .data$HR_log < 0, "Protective", "NS"))) %>%
     dplyr::mutate(Type = factor(Type, levels = c("NS", "Risky", "Protective")))
   ## visualization
-  p <- unicox_res_all_cancers_df %>% 
-    dplyr::mutate(cancer = factor(.data$cancer, levels=rev(.data$cancer))) %>% 
+  p <- unicox_res_all_cancers_df %>%
+    dplyr::mutate(cancer = factor(.data$cancer, levels = rev(.data$cancer))) %>%
     ggplot2::ggplot(
       aes_string(x = "cancer", y = "HR_log", ymin = "lower_95_log", ymax = "upper_95_log", color = "Type")
-  ) +
+    ) +
     ggplot2::theme_bw() +
     ggplot2::geom_pointrange() +
     ggplot2::coord_flip() +
@@ -463,8 +475,9 @@ vis_pancan_anatomy <- function(Gene = "TP53",
 #' p <- vis_gene_immune_cor(Gene = "TP53")
 #' }
 #' @export
-vis_gene_immune_cor <- function(Gene = "TP53", cor_method = "spearman", 
-  data_type = "mRNA", Immune_sig_type = "Cibersort", Plot = "TRUE", opt_pancan = .opt_pancan) {
+vis_gene_immune_cor <- function(
+    Gene = "TP53", cor_method = "spearman",
+    data_type = "mRNA", Immune_sig_type = "Cibersort", Plot = "TRUE", opt_pancan = .opt_pancan) {
   tcga_pan_immune_signature <- load_data("tcga_pan_immune_signature")
   tcga_gtex <- load_data("tcga_gtex")
 
@@ -475,7 +488,7 @@ vis_gene_immune_cor <- function(Gene = "TP53", cor_method = "spearman",
     tidyr::pivot_longer(3:ncol(.), names_to = "sample", values_to = "score") %>%
     dplyr::mutate(sample = stringr::str_sub(.data$sample, 1, 15))
 
-  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan=opt_pancan)
+  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan = opt_pancan)
   if (is.null(t1[[1]])) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
@@ -563,12 +576,13 @@ vis_gene_immune_cor <- function(Gene = "TP53", cor_method = "spearman",
 #' p <- vis_gene_tmb_cor(Gene = "TP53")
 #' }
 #' @export
-vis_gene_tmb_cor <- function(Gene = "TP53", cor_method = "spearman", 
+vis_gene_tmb_cor <- function(
+    Gene = "TP53", cor_method = "spearman",
     data_type = "mRNA", Plot = "TRUE", opt_pancan = .opt_pancan) {
   tcga_tmb <- load_data("tcga_tmb")
   tcga_gtex <- load_data("tcga_gtex")
 
-  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan=opt_pancan)
+  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan = opt_pancan)
   if (is.null(t1[[1]])) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
@@ -640,12 +654,12 @@ vis_gene_tmb_cor <- function(Gene = "TP53", cor_method = "spearman",
 #' p <- vis_gene_msi_cor(Gene = "TP53")
 #' }
 #' @export
-vis_gene_msi_cor <- function(Gene = "TP53", cor_method = "spearman", 
-      data_type = "mRNA", Plot = "TRUE",opt_pancan = .opt_pancan) {
+vis_gene_msi_cor <- function(Gene = "TP53", cor_method = "spearman",
+                             data_type = "mRNA", Plot = "TRUE", opt_pancan = .opt_pancan) {
   tcga_msi <- load_data("tcga_MSI")
   tcga_gtex <- load_data("tcga_gtex")
 
-  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan=opt_pancan)
+  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan = opt_pancan)
   if (is.null(t1[[1]])) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
@@ -741,8 +755,8 @@ vis_gene_msi_cor <- function(Gene = "TP53", cor_method = "spearman",
 #' #   group.colours = "#00AFBB") +
 #' #   theme(plot.title = element_text(hjust = .5))
 #' @export
-vis_gene_stemness_cor <- function(Gene = "TP53", cor_method = "spearman", 
-      data_type = "mRNA", Plot = "TRUE", opt_pancan = .opt_pancan) {
+vis_gene_stemness_cor <- function(Gene = "TP53", cor_method = "spearman",
+                                  data_type = "mRNA", Plot = "TRUE", opt_pancan = .opt_pancan) {
   tcga_stemness <- load_data("tcga_stemness")
   tcga_gtex <- load_data("tcga_gtex")
 
@@ -822,7 +836,7 @@ vis_toil_TvsN_cancer <- function(Gene = "TP53", Mode = c("Violinplot", "Dotplot"
                                  data_type = "mRNA", Show.P.value = FALSE,
                                  Show.P.label = FALSE, Method = "wilcox.test",
                                  values = c("#DF2020", "#DDDF21"),
-                                 TCGA.only = FALSE, Cancer = "ACC",opt_pancan = .opt_pancan) {
+                                 TCGA.only = FALSE, Cancer = "ACC", opt_pancan = .opt_pancan) {
   tcga_gtex <- load_data("tcga_gtex")
 
   Mode <- match.arg(Mode)
@@ -917,24 +931,26 @@ vis_toil_TvsN_cancer <- function(Gene = "TP53", Mode = c("Violinplot", "Dotplot"
 
     if (Show.P.value == TRUE & Show.P.label == TRUE) {
       if (TCGA.only == TRUE) stop("Can't compare with only one group")
-      p <- p + ggplot2::geom_text(aes(
-        x = 1.5,
-        y = max(data$value) * 1.1,
-        label = .data$p.signif
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        aes(
+          x = 1.5,
+          y = max(data$value) * 1.1,
+          label = .data$p.signif
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
     if (Show.P.value == TRUE & Show.P.label == FALSE) {
       if (TCGA.only == TRUE) stop("Can't compare with only one group")
-      p <- p + ggplot2::geom_text(aes(
-        x = 1.5,
-        y = max(data$value) * 1.1,
-        label = as.character(signif(.data$p, 2))
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        aes(
+          x = 1.5,
+          y = max(data$value) * 1.1,
+          label = as.character(signif(.data$p, 2))
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
   }
@@ -958,24 +974,26 @@ vis_toil_TvsN_cancer <- function(Gene = "TP53", Mode = c("Violinplot", "Dotplot"
 
     if (Show.P.value == TRUE & Show.P.label == TRUE) {
       if (TCGA.only == TRUE) stop("Can't compare with only one group")
-      p <- p + ggplot2::geom_text(ggplot2::aes(
-        x = 1.5,
-        y = max(data$value) * 1.1,
-        label = .data$p.signif
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        ggplot2::aes(
+          x = 1.5,
+          y = max(data$value) * 1.1,
+          label = .data$p.signif
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
     if (Show.P.value == TRUE & Show.P.label == FALSE) {
       if (TCGA.only == TRUE) stop("Can't compare with only one group")
-      p <- p + ggplot2::geom_text(ggplot2::aes(
-        x = 1.5,
-        y = max(data$value) * 1.1,
-        label = as.character(signif(.data$p, 2))
-      ),
-      data = pv,
-      inherit.aes = FALSE
+      p <- p + ggplot2::geom_text(
+        ggplot2::aes(
+          x = 1.5,
+          y = max(data$value) * 1.1,
+          label = as.character(signif(.data$p, 2))
+        ),
+        data = pv,
+        inherit.aes = FALSE
       )
     }
   }
@@ -1074,7 +1092,7 @@ vis_gene_cor <- function(Gene1 = "CSF1R",
       stringsAsFactors = FALSE
     ),
     by = "sample"
-  ) 
+  )
 
   df %>%
     dplyr::left_join(tcga_purity, by = "sample") -> df
@@ -1166,13 +1184,13 @@ vis_gene_cor_cancer <- function(Gene1 = "CSF1R",
     dplyr::distinct(.data$sample, .keep_all = TRUE)
 
   t1 <- query_pancan_value(Gene1, data_type = data_type1, opt_pancan = opt_pancan)
-  if (is.null(t1[[1]])) {
+  if (length(na.omit(t1[[1]])) == 0) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
   }
   if (is.list(t1)) t1 <- t1[[1]]
   t3 <- query_pancan_value(Gene2, data_type = data_type2, opt_pancan = opt_pancan)
-  if (is.null(t3[[1]])) {
+  if (length(na.omit(t1[[3]])) == 0) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
   }
@@ -1308,7 +1326,7 @@ vis_gene_TIL_cor <- function(Gene = "TP53",
   # we filter out normal tissue
   tcga_gtex <- tcga_gtex %>% dplyr::filter(.data$type2 != "normal")
 
-  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan=opt_pancan)
+  t1 <- query_pancan_value(Gene, data_type = data_type, opt_pancan = opt_pancan)
   if (is.null(t1[[1]])) {
     warning("No data available", immediate. = TRUE)
     return(NULL)
